==> httpcomponents-client-5.0.4-src.zip: httpclient5-cache/src/main/java/org/apache/hc/client5/http/impl/cache/HeapResource.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package org.apache.hc.client5.http.impl.cache;

import java.util.concurrent.atomic.AtomicReference;

import org.apache.hc.client5.http.cache.Resource;
import org.apache.hc.client5.http.cache.ResourceIOException;
import org.apache.hc.core5.annotation.Contract;
import org.apache.hc.core5.annotation.ThreadingBehavior;

/**
 * Cache resource backed by a byte array on the heap.
 *
 * @since 4.1
 */
@Contract(threading = ThreadingBehavior.IMMUTABLE)
public class HeapResource extends Resource {

    private static final long serialVersionUID = -2078599905620463394L;

    private final AtomicReference<byte[]> arrayRef;

    public HeapResource(final byte[] b) {
        super();
        this.arrayRef = new AtomicReference<>(b);
    }

    @Override
    public byte[] get() throws ResourceIOException {
        final byte[] byteArray = this.arrayRef.get();
        if (byteArray != null) {
            return byteArray;
        }
        throw new ResourceIOException("Resouce already dispoased");
    }

    @Override
    public long length() {
        final byte[] byteArray = this.arrayRef.get();
        if (byteArray != null) {
            return byteArray.length;
        } else {
            return -1;
        }
    }

    @Override
    public void dispose() {
        this.arrayRef.set(null);
    }

}

==> httpcomponents-client-5.5.1-src.zip: httpclient5-cache/src/main/java/org/apache/hc/client5/http/impl/cache/HeapResource.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package org.apache.hc.client5.http.impl.cache;

import java.util.concurrent.atomic.AtomicReference;

import org.apache.hc.client5.http.cache.Resource;
import org.apache.hc.client5.http.cache.ResourceIOException;
import org.apache.hc.core5.annotation.Contract;
import org.apache.hc.core5.annotation.ThreadingBehavior;

/**
 * Cache resource backed by a byte array on the heap.
 *
 * @since 4.1
 */
@Contract(threading = ThreadingBehavior.IMMUTABLE)
public class HeapResource extends Resource {

    private static final long serialVersionUID = -2078599905620463394L;

    private final AtomicReference<byte[]> arrayRef;

    public HeapResource(final byte[] b) {
        super();
        this.arrayRef = new AtomicReference<>(b);
    }

    @Override
    public byte[] get() throws ResourceIOException {
        final byte[] byteArray = this.arrayRef.get();
        if (byteArray != null) {
            return byteArray;
        }
        throw new ResourceIOException("Resource already disposed");
    }

    @Override
    public long length() {
        final byte[] byteArray = this.arrayRef.get();
        return byteArray != null ? byteArray.length : -1;
    }

    @Override
    public void dispose() {
        this.arrayRef.set(null);
    }

    @Override
    public String toString() {
        return "[" +
                "heap," +
                "len=" + length() +
                ']';
    }

}
